Struct frac_stake::instructions::shared::AuthorizationDataLocal
source · pub struct AuthorizationDataLocal {
pub payload: Vec<TaggedPayload>,
}Fields
payload: Vec<TaggedPayload>Trait Implementations
sourceimpl BorshDeserialize for AuthorizationDataLocalwhere
Vec<TaggedPayload>: BorshDeserialize,
impl BorshDeserialize for AuthorizationDataLocalwhere Vec<TaggedPayload>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl BorshSerialize for AuthorizationDataLocalwhere
Vec<TaggedPayload>: BorshSerialize,
impl BorshSerialize for AuthorizationDataLocalwhere Vec<TaggedPayload>: BorshSerialize,
sourceimpl Clone for AuthorizationDataLocal
impl Clone for AuthorizationDataLocal
sourcefn clone(&self) -> AuthorizationDataLocal
fn clone(&self) -> AuthorizationDataLocal
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AuthorizationDataLocal
impl Debug for AuthorizationDataLocal
sourceimpl From<AuthorizationDataLocal> for AuthorizationData
impl From<AuthorizationDataLocal> for AuthorizationData
sourcefn from(val: AuthorizationDataLocal) -> Self
fn from(val: AuthorizationDataLocal) -> Self
Converts to this type from the input type.